#encoding:utf-8
from django.db import models
from django.contrib.auth.models import User

# Create your models here.

class Estado(models.Model):
    nombre = models.CharField(verbose_name='Nombre', max_length=50)

    def __unicode__(self):
        return self.nombre

class Municipio(models.Model):
    id_estado = models.ForeignKey(Estado, verbose_name=u'Estado')
    nombre = models.TextField(verbose_name='Nombre')
    clave = models.CharField(max_length=15, null=True, blank=True)

    def __unicode__(self):
        return self.nombre

class Localidad(models.Model):
    id_municipio = models.ForeignKey(Municipio, verbose_name=u'Jurisdicción')
    nombre = models.TextField(verbose_name='Nombre')
    listo = models.CharField(max_length=2)

    def __unicode__(self):
        return self.nombre

class DerechoHabiente(models.Model):
    clave = models.TextField(verbose_name='Clave')
    descripcion = models.TextField(verbose_name='Descripción')

    def __unicode__(self):
        return self.descripcion

class Servicio(models.Model):
    descripcion = models.TextField(verbose_name='Descripción')

    def __unicode__(self):
        return self.descripcion

class Estatus(models.Model):
    descripcion = models.CharField(verbose_name='Descripción', max_length=100)

    def __unicode__ (self):
        return self.descripcion

class Tipo(models.Model):
    clave = models.CharField(verbose_name='Clave', max_length=15)
    descripcion = models.TextField(verbose_name='Descripción')
    fecha = models.DateField(verbose_name='Fecha')

    def __unicode__ (self):
        return u'[%s] %s' % (self.clave, self.descripcion)

class Nivel_Um(models.Model):
     descripcion = models.CharField(verbose_name='Descripción', max_length=200)
     fecha = models.DateField(verbose_name='Fecha', max_length=20)

     def __unicode__(self):
        return self.descripcion

class Nivel(models.Model):
    tipo = models.CharField(verbose_name='Tipo', max_length=20)
    clave = models.CharField(verbose_name='Clave', max_length=20)
    descripcion = models.CharField(verbose_name='Descripción', max_length=200)

    def __unicode__(self):
        return self.descripcion

class Metas_Mensual(models.Model):
    detecciones = models.CharField(verbose_name='Detección', max_length=200)
    subsecuentes = models.CharField(verbose_name='Subsecuente', max_length=200)
    id_nivel_um = models.ForeignKey(Nivel_Um, verbose_name=u'Nivel de Unidad Medica')

    def __unicode__(self):
        return self.detecciones

class Cie_10(models.Model):
    letra = models.CharField(verbose_name='Letra', max_length=5)
    causa = models.CharField(verbose_name='Causa', max_length=200)
    a = models.CharField(verbose_name='A', max_length=15)
    nombre = models.CharField(verbose_name='Nombre', max_length=400)
    anio_modif = models.CharField(verbose_name='Año de modificación', max_length=400, null=True, blank=True)
    id_estatus = models.ForeignKey(Estatus, verbose_name=u'Estatus')

    def __unicode__(self):
        return self.causa

class Tx_Farm(models.Model):
    clave = models.CharField(verbose_name='Clave', max_length=20)
    descripcion = models.CharField(verbose_name='Descripción', max_length=200)
    id_estatus = models.ForeignKey(Estatus, verbose_name=u'Estatus')

    def __unicode__(self):
        return self.descripcion

class Tipo_Profesion(models.Model):
    clave = models.CharField(verbose_name='Clave', max_length=20)
    descripcion = models.CharField(verbose_name='Descripción', max_length=200)

    def __unicode__(self):
        return self.descripcion

class Tipo_Egreso(models.Model):
    descripcion = models.CharField(verbose_name='Descripción', max_length=200)

    def __unicode__(self):
        return self.descripcion

class Unidad_Medica(models.Model):
    tipounidad = models.CharField(verbose_name='Tipo de Unidad', max_length=200)
    clave = models.CharField(verbose_name='Clave', max_length=15)
    nombre = models.CharField(verbose_name='Nombre', max_length=150)
    id_estatus = models.ForeignKey(Estatus, verbose_name=u'Estatus', default=1)
    id_localidad = models.ForeignKey(Localidad, verbose_name=u'Localidad')
    id_tipo = models.ForeignKey(Tipo, verbose_name=u'Tipo')
    id_nivel_um = models.ForeignKey(Nivel_Um, verbose_name=u'Nivel de Unidad Medica')

    def __unicode__(self):
        return self.nombre

class Responsable_Atencion(models.Model):
    id_tipo_prof = models.ForeignKey(Tipo_Profesion, verbose_name=u'Tipo Profesion')
    id_municipio = models.ForeignKey(Municipio, verbose_name=u'Jurisdicción')
    id_unidad_medica = models.ForeignKey(Unidad_Medica, verbose_name=u'Unidad Medica',null=True, blank=True)
    nombre = models.CharField(verbose_name='Nombre', max_length=30)
    ap_paterno = models.CharField(verbose_name='Apellido Paterno', max_length=30)
    ap_materno = models.CharField(verbose_name='Apellido Materno', max_length=30)
    edad = models.IntegerField(verbose_name='Edad', null=True, blank=True)
    id_estatus = models.ForeignKey(Estatus, verbose_name=u'Estatus', default=1)


    def __unicode__(self):
        return self.nombre

SEXO_CHOICES = (
   ('H', 'Hombre'),
   ('M', 'Mujer'),
)


class Paciente(models.Model):
    rfc = models.CharField(verbose_name='RFC', max_length=20, help_text='Ingrese su RFC')
    nombre = models.CharField(verbose_name='Nombre', max_length=200)
    ap_paterno = models.CharField(verbose_name='Apellido Paterno', max_length=100)
    ap_materno = models.CharField(verbose_name='Apellido Materno', max_length=100)
    sexo = models.CharField(verbose_name='Sexo', max_length=10, choices=SEXO_CHOICES)
    edad = models.IntegerField(verbose_name='Edad', max_length=3)
    id_derechohabiente = models.ForeignKey(DerechoHabiente, verbose_name=u'DerechoHabiente')
    id_municipio = models.ForeignKey(Municipio, verbose_name=u'Jurisdicción')
    id_user = models.ForeignKey(User, verbose_name=u'Usuario')
    id_estado = models.ForeignKey(Estado, verbose_name=u'Estado')

    def __unicode__(self):
        return self.nombre

class Hist_Datos_Pacientes(models.Model):
    id_paciente = models.ForeignKey(Paciente, verbose_name=u'Paciente')
    fecha_Modif = models.DateTimeField(verbose_name='Fecha de modificación',auto_now=True)
    id_derechohabiente = models.ForeignKey(DerechoHabiente, verbose_name=u'DerechoHabiente')
    id_municipio = models.ForeignKey(Municipio, verbose_name=u'Jurisdicción')
    id_user = models.ForeignKey(User, verbose_name=u'Usuario')
    id_estado = models.ForeignKey(Estado, verbose_name=u'Estado')

    def __unicode__(self):
        return self.id_paciente

class Deteccion(models.Model):
    fecha_atencion = models.DateField(verbose_name='Fecha de Atención')
    tipo_riesgo = models.CharField(verbose_name='Tipo de riesgo', max_length=40)
    id_paciente = models.ForeignKey(Paciente, verbose_name=u'Paciente')
    id_municipio = models.ForeignKey(Municipio, verbose_name=u'Jurisdicción')
    id_servicio = models.ForeignKey(Servicio, verbose_name=u'Servicio')
    id_responsable_atencion = models.ForeignKey(Responsable_Atencion, verbose_name=u'Responsable de Atencion')
    id_tx_farm = models.ForeignKey(Tx_Farm, verbose_name=u'Tx Farm')
    id_unidad_medica = models.ForeignKey(Unidad_Medica, verbose_name=u'Unidad Medica')
    id_cie_10 = models.ForeignKey(Cie_10, verbose_name=u'Cie 10')
    num_aplicacion = models.CharField(verbose_name='Número de aplicación', max_length=10,null=True, blank=True)
    id_nivel = models.ForeignKey(Nivel, verbose_name=u'Nivel',null=True, blank=True)
    id_estatus = models.ForeignKey(Estatus, verbose_name=u'Estatus')
    id_user = models.ForeignKey(User, verbose_name=u'Usario')
    id_estado = models.ForeignKey(Estado, verbose_name=u'Estado')

    def __unicode__(self):
        return self.tipo_riesgo

class Subsecuente(models.Model):
    fecha = models.DateField(verbose_name=u'Fecha')
    id_deteccion = models.ForeignKey(Deteccion, verbose_name=u'Deteccion')
    id_user = models.ForeignKey(User, verbose_name=u'Usuario')
    seguimiento = models.CharField(max_length=2, verbose_name=u'Seguimiento')

    def __unicode__(self):
        return self.id_deteccion

class Egreso(models.Model):
    fecha = models.DateField(verbose_name=u'Fecha')
    num_aplicacion = models.CharField(max_length=10, verbose_name=u'Número de aplicación',null=True, blank=True)
    referencia = models.CharField(max_length=40, verbose_name=u'Referencia',null=True, blank=True)
    id_deteccion = models.ForeignKey(Deteccion, verbose_name=u'Detección')
    id_nivel = models.ForeignKey(Nivel, verbose_name=u'Nivel',null=True, blank=True)
    id_tipo_egreso = models.ForeignKey(Tipo_Egreso, verbose_name=u'Tipo Egreso')
    id_user = models.ForeignKey(User, verbose_name=u'Usuario')

    def __unicode__(self):
        return self.referencia
